@@ -12,7 +12,7 @@ from autograde.cli.report import cmd_report
 from autograde.cli.summary import cmd_summary
 from autograde.cli.test import cmd_tst
 from autograde.cli.version import cmd_version
-from autograde.util import logger, loglevel
+from autograde.util import logger, loglevel, project_root
 
 
 def cli(args=None):
@@ -85,10 +85,12 @@ def cli(args=None):
     args = parser.parse_args(args)
 
     logger.setLevel(loglevel(args.verbose))
+    logger.debug(f'python: {sys.executable}')
+    logger.debug(f'autograde: {project_root()}')
     logger.debug(f'default encoding: {sys.getdefaultencoding()}')
     logger.debug(f'args: {args}')
 
-    return args.func(args)
+    return args.func(args) or 0
 
 
 if __name__ == '__main__':
